@@ -110,9 +110,8 @@ class TestSourcesDefaultOrg(unittest.TestCase):
             file_path="tests/data_test.csv"
         )
 
-        self.assertTrue("truncate" in export, export)
         self.assertTrue("stage" in export, export)
-        self.assertTrue("append" in export, export)
+        self.assertTrue("overwrite" in export, export)
 
     def test_truncate_data_set(self):
         export = self.sources.truncate_data_set(
