@@ -77,12 +77,15 @@ class OrgAdmin(ApiRequestManager):
 
         self.verify_properties(cluster_name=self.cluster)
 
+        headers = self.build_header(
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            others=self.content_type_header
+        )
+
         jobs = self.session.get(
             self.org_info_url.format(org_id),
-            headers=self.build_header(
-                aut_token=self.props.get_auth_token(cluster=self.cluster),
-                org_id=org_id,
-                others=self.content_type_header)
+            headers=headers
         )
 
         return json.loads(jobs.content), jobs.status_code
@@ -99,7 +102,8 @@ class OrgAdmin(ApiRequestManager):
         try:
 
             header = self.build_header(
-                others={"Content-Type": "application/json"}
+                aut_token=self.props.get_auth_token(cluster=self.cluster),
+                others=self.content_type_header
             )
 
             submit_report = self.session.put(
@@ -131,6 +135,11 @@ class OrgAdmin(ApiRequestManager):
             if org_name is None:
                 org_name = str(uuid.uuid4())
 
+            header = self.build_header(
+                aut_token=self.props.get_auth_token(cluster=self.cluster),
+                others=self.content_type_header
+            )
+
             payload = {
                 "name": str(org_name),
                 "piTagExportLimit": self.pi_tag_export_limit,
@@ -138,7 +147,7 @@ class OrgAdmin(ApiRequestManager):
 
             org_create_post = self.session.post(
                 self.orgs_api_url,
-                headers=self.build_header(others=self.content_type_header),
+                headers=header,
                 data=json.dumps(payload)
             )
 
@@ -166,8 +175,14 @@ class OrgAdmin(ApiRequestManager):
                 cluster=self.cluster
             ) + 'api/management/v1/orgs/' + str(org_id)
 
+            header = self.build_header(
+                aut_token=self.props.get_auth_token(cluster=self.cluster),
+                others=self.content_type_header
+            )
+
             delete_request = self.session.delete(
-                delete_endpoint
+                delete_endpoint,
+                headers=header
             )
 
             if delete_request.status_code == 200:
@@ -199,6 +214,7 @@ class OrgAdmin(ApiRequestManager):
 
             header = self.build_header(
                 org_id=org_id,
+                aut_token=self.props.get_auth_token(cluster=self.cluster),
                 others=self.content_type_header
             )
 
@@ -240,6 +256,7 @@ class OrgAdmin(ApiRequestManager):
 
             header = self.build_header(
                 org_id=org_id,
+                aut_token=self.props.get_auth_token(cluster=self.cluster),
                 others=self.content_type_header
             )
 
@@ -272,7 +289,14 @@ class OrgAdmin(ApiRequestManager):
         """
         try:
 
-            request = self.session.get(self.who_ami_url)
+            header = self.build_header(
+                aut_token=self.props.get_auth_token(cluster=self.cluster)
+            )
+
+            request = self.session.get(
+                self.who_ami_url,
+                headers=header
+            )
 
             if request.status_code == 200:
                 return json.loads(request.content)["organizations"]
@@ -347,6 +371,7 @@ class OrgAdmin(ApiRequestManager):
         """
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -405,6 +430,7 @@ class OrgAdmin(ApiRequestManager):
         """
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -435,6 +461,7 @@ class OrgAdmin(ApiRequestManager):
         """
 
         header = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -465,6 +492,7 @@ class OrgAdmin(ApiRequestManager):
         try:
 
             header = self.build_header(
+                aut_token=self.props.get_auth_token(cluster=self.cluster),
                 others=self.different_content_type
             )
 
