@@ -354,7 +354,7 @@ class Pipelines(ApiRequestManager):
         raise Exception(repr(post_upload_file.content))
 
     @single_org
-    def create_pipeline(self, name, org_id=None, function=False):
+    def create_pipeline(self, name, org_id=None, function=False, is_stream=False):
         """
         Creates an empty pipeline
 
@@ -364,6 +364,8 @@ class Pipelines(ApiRequestManager):
         :type org_id: int or str
         :param function: Defines if the pipeline is a function or not
         :type function: boolean
+        :param is_stream: Define if the pipeline is a stream pipeline
+        :type is_stream: boolean
         :return:
         """
 
@@ -373,7 +375,7 @@ class Pipelines(ApiRequestManager):
             others=self.content_type_header
         )
 
-        payload = {"name": name, "components": []}
+        payload = {"name": name, "components": [], "isStream": is_stream}
 
         if function:
             payload["pipelineType"] = "function"
