@@ -48,18 +48,18 @@ class Properties:
     Class respresenting cluster properties
     """
 
-    _instance = None
+    _instances = {}
     _lock = threading.Lock()
 
     def __new__(cls, clusterSetting=ClusterSetting.KEY_RING):
         """
         Override __new__ to implement singleton semantics. Note that this is also threadsafe.
         """
-        if cls._instance is None:
+        if cls._instances.get(clusterSetting) is None:
             with cls._lock:
-                if not cls._instance:
-                    cls._instance = super().__new__(cls)
-        return cls._instance
+                if cls._instances.get(clusterSetting) is None:
+                    cls._instances[clusterSetting] = super().__new__(cls)
+        return cls._instances[clusterSetting]
 
     def __init__(self, clusterSetting=ClusterSetting.KEY_RING):
         """
@@ -68,17 +68,29 @@ class Properties:
         :param clusterSetting: Cluster settings to decide if use keyring, memory or file
         :type clusterSetting: `unify.properties.Properties.Enum`
         """
-        self._SYSTEM = "ah"
-        self._REMOTE = "d0adae9c-a1b7-11ea-906d-acde48001122_{}"
-        self._AUTHTOKEN = "c8f9465c-a1b7-11ea-906d-acde48001122_{}"
-        self._USERNAME = "c2c731a4-a1b7-11ea-906d-acde48001122_{}"
-        self._PASSWORD = "b901bcca-a1b7-11ea-906d-acde48001122_{}"
-        self._NAMES = '23556a06-a1c0-11ea-906d-acde48001122'
-        self._DEFAULT = '69a9e665-bdd0-40aa-b729-735c8997d3f6'
-        self._ASSETSYNC = 'cc61e5c1-ab56-43cb-b848-f342eaafc90c_{}'
 
-        self.clusters = {}
-        self.clusterSetting = clusterSetting
+        # If it's already initialized, just return
+        if hasattr(self, '_initialized'):
+            return
+
+        # Ensure only one thread can be in the following block
+        with self.__class__._lock:
+            # Check again inside the lock to ensure that the object didn't
+            # get initized before the lock was entered.
+            if not hasattr(self, '_initialized'):
+                self._SYSTEM = "ah"
+                self._REMOTE = "d0adae9c-a1b7-11ea-906d-acde48001122_{}"
+                self._AUTHTOKEN = "c8f9465c-a1b7-11ea-906d-acde48001122_{}"
+                self._USERNAME = "c2c731a4-a1b7-11ea-906d-acde48001122_{}"
+                self._PASSWORD = "b901bcca-a1b7-11ea-906d-acde48001122_{}"
+                self._NAMES = '23556a06-a1c0-11ea-906d-acde48001122'
+                self._DEFAULT = '69a9e665-bdd0-40aa-b729-735c8997d3f6'
+                self._ASSETSYNC = 'cc61e5c1-ab56-43cb-b848-f342eaafc90c_{}'
+
+                self.clusters = {}
+                self.clusterSetting = clusterSetting
+
+                self._initialized = True
 
     def __enter__(self):
         return self
