@@ -37,7 +37,7 @@ class Sources(ApiRequestManager):
     Class to interact with dataset endpoints
     """
 
-    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING), org_id=None):
+    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING), org_id=None, session=None):
         """
         Class constructor
 
@@ -47,7 +47,7 @@ class Sources(ApiRequestManager):
         :type props: class:`unify.properties.Properties`
         """
 
-        super().__init__(cluster=cluster, props=props, org_id=org_id)
+        super().__init__(cluster=cluster, props=props, org_id=org_id, session=session)
 
         try:
 
@@ -98,7 +98,7 @@ class Sources(ApiRequestManager):
                 self.cluster) + "tags/org/{}/datasets/{}/preview"
 
             self.dataset_info_url = self.props.get_remote(
-                self.cluster) + "tags/org/{}/pipelines/v2/datasets"
+                self.cluster) + "datasets/v1/dataset/{}/info"
 
             self.gql_builder = DatasetGrapql()
 
@@ -760,11 +760,6 @@ class Sources(ApiRequestManager):
         """
         response = {}
 
-        response["truncate"] = self.truncate_data_set(
-            org_id=org_id,
-            data_set_id=data_set_id
-        )
-
         name = "overwirte{}".format(int(time.time()))
 
         response["stage"] = self.stage_data(
@@ -777,13 +772,13 @@ class Sources(ApiRequestManager):
             encoding=encoding,
             encode=encode
         )
-
-        response["append"] = self.append_command(
-            org_id=org_id,
-            data_set_id=data_set_id,
-            group_id=response["stage"],
-            name=name
-        )
+        command = {
+            "commands":
+                [
+                    self.single_overwrite_command(group_id=response["stage"], name=name)
+                ]
+        }
+        response["overwrite"] = self._commit_dataset_command(org_id, data_set_id, command)
 
         return response
 
@@ -796,7 +791,7 @@ class Sources(ApiRequestManager):
 
         headers = dict(header.items())
         request = self.session.post(
-            self.commit_data_set_url.format(data_set_id),
+            url=self.commit_data_set_url.format(data_set_id),
             headers=headers,
             json=command
         )
@@ -814,7 +809,7 @@ class Sources(ApiRequestManager):
 
             return append
         else:
-            raise Exception(repr(request.content))
+            raise Exception("commit to {} fails".format(data_set_id) + repr(request.content))
 
     @single_org
     def truncate_data_set(self, org_id=None, *, data_set_id):
@@ -986,7 +981,7 @@ class Sources(ApiRequestManager):
             params=payload_data
         )
 
-        return test_request.content
+        return test_request.content.decode()
 
     def stage_file(self, name, org_id, file_path, group_id=None, format="csv",
                    convert_to_parquet="false", encoding='UTF-8', encode=False):
@@ -1012,7 +1007,7 @@ class Sources(ApiRequestManager):
         :return:
         """
 
-        file_data = open(file_path, "r").read().encode(encoding)
+        file_data = open(file_path, "r").read()
 
         return self.stage_file_with_content(
             name=name,
@@ -1080,7 +1075,10 @@ class Sources(ApiRequestManager):
             params=payload_data
         )
 
-        return test_request.content
+        if test_request.status_code in [200, 202]:
+            return test_request.content.decode()
+        else:
+            raise Exception("Failed to stage file, org {}, status code: {}, error: {}".format(org_id, test_request.status_code, test_request.content))
 
     def post_file_schema(self, org_id, schema_data, encoding='UTF-8'):
         """
@@ -1382,7 +1380,7 @@ class Sources(ApiRequestManager):
         data = [("dataset_id", dataset_id)]
 
         get_response = self.session.get(
-            self.dataset_info_url.format(org_id),
+            self.dataset_info_url.format(dataset_id),
             headers=headers,
             params=data
         )
@@ -1576,7 +1574,10 @@ class Sources(ApiRequestManager):
 
     def single_append_command(self, group_id, name):
 
-        return {"$type": "append", "name": name, "group": group_id.decode(), "cause": []}
+        return {"$type": "append", "name": name, "group": group_id, "cause": []}
+
+    def single_overwrite_command(self, group_id, name):
+        return {"$type": "overwrite", "name": name, "group": group_id, "cause": []}
 
     def single_create_command(self, schema, org_id, name, is_stream, facets, description, cause):
         return {
