@@ -110,7 +110,8 @@ class Templates(ApiRequestManager):
             file_upload = {'file': file_path}
 
         upload_headers = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         post_upload_template = self.session.post(
@@ -138,7 +139,8 @@ class Templates(ApiRequestManager):
         final_url = self.template_attribute.format(org_id, template_id)
 
         upload_headers = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         get_attrs = self.session.get(
@@ -167,7 +169,8 @@ class Templates(ApiRequestManager):
         files = {'file': ('templates_uploads.csv', content, self.upload_content_type)}
 
         upload_headers = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         post_upload_template = self.session.post(
@@ -231,7 +234,8 @@ class Templates(ApiRequestManager):
         }
 
         upload_headers = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         post_upload_template = self.session.post(
@@ -250,6 +254,7 @@ class Templates(ApiRequestManager):
         url = self.categories_url.format(org_id)
         headers = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
         payload = {
@@ -276,6 +281,7 @@ class Templates(ApiRequestManager):
         """
         headers = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
         request = self.session.get(
             self.categories_url.format(org_id),
@@ -319,6 +325,7 @@ class Templates(ApiRequestManager):
         url = '{}/{}?version={}'.format(self.template_url, template_id, version)
         headers = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
         payload = {
@@ -350,7 +357,8 @@ class Templates(ApiRequestManager):
         :return: Retrieved template str
         """
         header = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
         url = self.template_url + '/' + str(template_id)
         request = self.session.get(url, headers=header)
@@ -371,7 +379,8 @@ class Templates(ApiRequestManager):
         """
 
         header = self.build_header(
-            org_id=org_id
+            org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster)
         )
 
         list_request = self.session.get(self.root_templete_url, headers=header)
@@ -399,6 +408,7 @@ class Templates(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -482,7 +492,8 @@ class Templates(ApiRequestManager):
         try:
 
             header = self.build_header(
-                org_id=org_id
+                org_id=org_id,
+                aut_token=self.props.get_auth_token(cluster=self.cluster)
             )
 
             url = self.template_batch_url.format(org_id)
@@ -589,6 +600,7 @@ class Templates(ApiRequestManager):
 
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
@@ -613,6 +625,7 @@ class Templates(ApiRequestManager):
         """
         header = self.build_header(
             org_id=org_id,
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
             others=self.content_type_header
         )
 
